Learn R Programming

GHCNr (version 1.4.6)

download_inventory: Download GHCNd Inventory File

Description

Download GHCNd Inventory File

Usage

download_inventory(filename)

Value

Character, the location of the file where the inventory has been saved.

Arguments

filename

Character of the filename of the inventory, if already downloaded.

Details

Download the inventory from <"https://www.ncei.noaa.gov/pub/data/ghcn/daily/ghcnd-inventory.txt">.

Examples

Run this code
if (FALSE) {
download_inventory(...)
}

Run the code above in your browser using DataLab