period_coverage() calculates how many days have been recorded for
the whole time period.
Usage
period_coverage(x)
Value
A table with period coverage.
Arguments
x
Object of class ghcn_daily. See daily() for details.
Details
To calculate the coverage, a full daily time range is full joined to the
timeseries. Missing days are set to NA. Coverage is then calculated as
the number of values that are not NAs over the number of NAs.
Period coverage is a constant value for each station in the ghcn_daily
object.