powered by
Download GHCNd Inventory File
download_inventory(filename)
Character, the location of the file where the inventory has been saved.
Character of the filename of the inventory, if already downloaded.
Download the inventory from <"https://www.ncei.noaa.gov/pub/data/ghcn/daily/ghcnd-inventory.txt">.
if (FALSE) { download_inventory(...) }
Run the code above in your browser using DataLab